
# Slot: subject


the material sample being described

URI: [biolink:material_sample_derivation_association_subject](https://w3id.org/biolink/vocab/material_sample_derivation_association_subject)


## Domain and Range

[MaterialSampleDerivationAssociation](MaterialSampleDerivationAssociation.md) &#8594;  <sub>1..1</sub> [MaterialSample](MaterialSample.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [MaterialSampleDerivationAssociation](MaterialSampleDerivationAssociation.md)
